ALBUM = "album"
AUDIOBOOK = "audiobook"
BOOK = "book"
CHAPTER = "chapter"
COMIC = "comic"
DOCUMENT = "document"
MOVIE = "movie"
MUSIC = "music"
PODCAST = "podcast"
SPECIAL = "special"
SUBSCRIPTION = "subscription"
VIDEO = "video"


MEDIA_TYPES = [
    ALBUM,
    AUDIOBOOK,
    BOOK,
    CHAPTER,
    COMIC,
    DOCUMENT,
    MOVIE,
    MUSIC,
    PODCAST,
    SPECIAL,
    SUBSCRIPTION,
    VIDEO,
]
