AIRDROP = "airdrop"
FLASH = "flash"
GIVEAWAY = "giveaway"
MINT = "mint"
SALE = "sale"
SPECIAL = "special"
SUBSCRIPTION = "subscription"


RELEASE_TYPES = [
    AIRDROP,
    FLASH,
    GIVEAWAY,
    MINT,
    SALE,
    SPECIAL,
    SUBSCRIPTION,
]
